<?php
/**
 * Manage the database of the ad group
 * Description: the type of value's index : id, name, kind, amount, notes, type, date, sort, numberdatas
 *
 * Version: 1.0.0
 *
 */
include_once(dirname(__FILE__)."/Formatting_Data.php");
include_once(dirname(__FILE__)."/Ad_Groups_DB_WPTO.php");

class Ads_DB_WPTO extends Formatting_Data {

	public $tb_nm; // The name of table.

	/**
	 * Contructor of this class.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @param	string	$tb_nm			The name of table
	 */
	function __construct() {
		global $wpdb;
		$this->tb_nm = $wpdb->prefix . "wpsite_takeover_ads";
		$wpdb->query("
			CREATE TABLE IF NOT EXISTS `" . $this->tb_nm . "` (
				`ad_id` int(11) NOT NULL AUTO_INCREMENT,
				`ad_name` varchar(60) NOT NULL DEFAULT '',
				`ad_type` int(1) NOT NULL DEFAULT '1',
				`ad_group` int(1) NOT NULL,
				`start_date` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
				`end_date` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
				`priority` int(1) NOT NULL DEFAULT '1',

				`is_front_page` tinyint(1) NOT NULL DEFAULT '0',
				`is_category` tinyint(1) NOT NULL DEFAULT '0',
				`is_tag` tinyint(1) NOT NULL DEFAULT '0',
				`is_archive` tinyint(1) NOT NULL DEFAULT '0',
				`is_single` tinyint(1) NOT NULL DEFAULT '0',
				`is_page` tinyint(1) NOT NULL DEFAULT '0',
				`post_id` varchar(60) NOT NULL DEFAULT '',
				`category_id` varchar(60) NOT NULL DEFAULT '',
				`page_id` varchar(60) NOT NULL DEFAULT '',
				`img_id` int(11) NOT NULL DEFAULT '0',

				`other_val` longtext,
				`args`		longtext,
				`active_fg` tinyint(1) NOT NULL DEFAULT '2',
				PRIMARY KEY (`ad_id`)
			) ENGINE=InnoDB DEFAULT CHARSET=latin1 AUTO_INCREMENT=1;
		");
	}

	/**
	 * Add data.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @param	array	$val	description
	 * @return	mixed			The new inserted ID on successful, false on failure.
	 */
	public function add_data($val, $other_val) {
		global $wpdb;

		if(is_array($val) || $val['ad_name'] != "") {
			$result = $wpdb->query($wpdb->prepare("INSERT INTO {$this->tb_nm} (
				ad_name,
				ad_type,
				ad_group,
				start_date,
				end_date,
				priority,
				is_front_page,
				is_category,
				is_tag,
				is_archive,
				is_single,
				is_page,
				post_id,
				category_id,
				page_id,
				img_id,
				other_val,
				args
				) VALUES (%s, %d, %d, %s, %s, %d, %d, %d, %d, %d, %d, %d, %s, %s, %s, %d, %s, %s
			)", $val['ad_name'],
				$val['ad_type'],
				$val['ad_group'],
				$val['start_date'],
				$val['end_date'],
				$val['priority'],
				$val['is_front_page'],
				$val['is_category'],
				$val['is_tag'],
				$val['is_archive'],
				$val['is_single'],
				$val['is_page'],
				$val['post_id'],
				$val['category_id'],
				$val['page_id'],
				$val['img_id'],
				parent::maybe_serialize($other_val),
				$val['args']
			));
		}

		if(!isset($result)) return false;

		return $wpdb->insert_id;
	}

	/**
	 * update datas.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @param	int		$id		description
	 * @param	array	$val	description
	 * @return	mix				The id on successful, false on failure.
	 */
	public function update_data($val, $other_val) {
		global $wpdb;
		if(!is_array($val) || $val['ad_id'] == "")
			return FALSE;

		$tmp = $this->get_datas_byid($val['ad_id']);
		if($tmp["basic_val"]["img_id"] != $val["img_id"])
			wp_delete_attachment($tmp["basic_val"]["img_id"]);

		$wpdb->query($wpdb->prepare("UPDATE {$this->tb_nm} SET
			ad_name = %s,
			ad_type = %d,
			ad_group = %d,
			start_date = %s,
			end_date = %s,
			priority = %d,

			is_front_page = %d,
			is_category = %d,
			is_tag = %d,
			is_archive = %d,
			is_single = %d,
			is_page = %d,
			post_id = %s,
			category_id = %s,
			page_id = %s,
			img_id = %d,

			other_val = %s,
			args = %s
			WHERE ad_id = %d",

			$val['ad_name'],
			$val['ad_type'],
			$val['ad_group'],
			$val['start_date'],
			$val['end_date'],
			$val['priority'],
			$val['is_front_page'],
			$val['is_category'],
			$val['is_tag'],
			$val['is_archive'],
			$val['is_single'],
			$val['is_page'],
			$val['post_id'],
			$val['category_id'],
			$val['page_id'],
			$val['img_id'],
			parent::maybe_serialize( $other_val ),
			$val['args'],
			$val['ad_id']));
	}

	/**
	 * get the count of active an inactive.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @param	array	$cond	description
	 * @return	mixed			The datas array on successful, false on failure.
	 */
	public function get_datas_cnt() {
		global $wpdb;
		$results = $wpdb->get_results("SELECT COUNT(`ad_id`) AS cnt, active_fg AS active_fg FROM {$this->tb_nm} GROUP BY `active_fg`");

		if(!$results) return FALSE;

		$vals = array();
		foreach ($results as $result) {
			if($result->active_fg == 1)
				$vals["inactive"] = $result->cnt;
			if($result->active_fg == 2)
				$vals["active"] = $result->cnt;
		}
		return $vals;
	}

	/**
	 * Get the data by id.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @param	array	$cond	description
	 * @return	mixed			The datas array on successful, false on failure.
	 */
	public function get_datas_byid($id) {
		global $wpdb;
		$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE `ad_id` = %d", $id));

		if(!$results) return FALSE;

		foreach ($results as $result) {
			$val = array();

			$val["ad_id"]		= $result->ad_id;
			$val["ad_name"]		= $result->ad_name;
			$val["ad_type"] 	= $result->ad_type;
			$val["ad_group"]	= $result->ad_group;
			$val["start_date"]	= $result->start_date;
			$val["end_date"]	= $result->end_date;
			$val["priority"] 	= $result->priority;

			$val["is_front_page"] 		= $result->is_front_page;
			$val["is_category"] 		= $result->is_category;
			$val["is_tag"] 				= $result->is_tag;
			$val["is_archive"] 			= $result->is_archive;
			$val["is_single"] 			= $result->is_single;
			$val["is_page"] 			= $result->is_page;
			$val["post_id"]				= $result->post_id;
			$val["category_id"]			= $result->category_id;
			$val["page_id"]				= $result->page_id;
			$val["img_id"]				= $result->img_id;

			$val["active_fg"]			= $result->active_fg;
			$vals['args']				= $result->args;

			$vals["basic_val"]			= $val;
			$vals["other_val"]			= parent::maybe_unserialize( $result->other_val );
		}

		return $vals;
	}

	/**
	 * Get the list of data.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @param	array	$cond	description
	 * @return	mixed			The datas array on successful, false on failure.
	 */
	public function get_datas_for_list($cond = array()) {
		global $wpdb;
		$adGroupsMgn = new Ad_Groups_Mgn();

		$groups = array();
		$groups = $adGroupsMgn->get_datas();

		$group_nms = array();

		for ($i = 0; $i < count($groups); $i++) {
			$group_nms[$groups[$i]["id"]] = $groups[$i]["name"];
		}

		/* There is not active or orderby sort */

		/*
if (!isset($cond['active_fg']) && !isset($cond['orderby'])) {
			//$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE `ad_name` LIKE %s", '%' . like_escape($cond['s']) . '%'));
			$results = $wpdb->get_results("SELECT * FROM {$this->tb_nm}");
		}
*/

		/* There is an active by sort */

		if (isset($cond['active_fg']) && !isset($cond['orderby']) && $cond['active_fg'] != "") {
			//$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE `ad_name` LIKE %s AND `active_fg` = %d", '%' . like_escape($cond['s']) . '%', $cond['active_fg']));
			$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE `active_fg` = %d", $cond['active_fg']));
		}

		/* There is orderby sort */

		else if (isset($cond['orderby']) && !isset($cond['active_fg']) && $cond['orderby'] != "") {
			//$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE `ad_name` LIKE %s ORDER BY %s %s", '%' . like_escape($cond['s']) . '%', $cond['orderby'], $cond['order']));
			$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} ORDER BY %s %s", $cond['orderby'], $cond['order']));
		}

		/* There is an active by and order by sort */

		else if (isset($cond['active_fg']) && isset($cond['orderby']) && $cond['orderby'] != "" && $cond['active_fg'] != "") {
			//$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE `ad_name` LIKE %s AND `active_fg` = %d ORDER BY %s %s", '%' . like_escape($cond['s']) . '%', $cond['active_fg'], $cond['orderby'], $cond['order']));
			$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE `active_fg` = %d ORDER BY %s %s", $cond['active_fg'], $cond['orderby'], $cond['order']));
		}

		/* There are no parameters */

		else {
			$results = $wpdb->get_results("SELECT * FROM {$this->tb_nm}");
		}

		$vals = array();
		if(!isset($results)) return FALSE;

		foreach ($results as $result) {
			$val = array();

			$val["ad_id"]		= $result->ad_id;
			$val["ad_name"]		= $result->ad_name;

			if($result->ad_type == 1)
				$val["ad_type"] = "Wallpaper";
			if($result->ad_type == 2)
				$val["ad_type"] = "Page";
			if($result->ad_type == 3)
				$val["ad_type"] = "720 * 90";
			if($result->ad_type == 4)
				$val["ad_type"] = "300 * 250";

			$val["ad_group"]		= $group_nms[$result->ad_group];
			$val["start_date"]		= $result->start_date;
			$val["end_date"]		= $result->end_date;

			if($result->priority == 1)
				$val["priority"] = "High";
			if($result->priority == 2)
				$val["priority"] = "Medium";
			if($result->priority == 3)
				$val["priority"] = "Low";

			if($result->active_fg == 1)
				$val["active_fg"] = "Inactive";
			if($result->active_fg == 2)
				$val["active_fg"] = "Active";

			$val["img_id"] = $result->img_id;
			$vals[]		= $val;
		}
		return $vals;
	}

	/**
	 * Advertising is set to active or inactive
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @param	int		$id			description
	 * @param	bool	$file_fg	description
	 * @return	bool				true on successful, false on failure.
	 */
	public function set_active($id, $fg) {
		global $wpdb;

		if (!is_numeric($fg)) {
			if ($fg == 'inactivate') {
				$fg = 1;
			}else {
				$fg = 2;
			}
		}

		$result = $wpdb->query($wpdb->prepare("UPDATE {$this->tb_nm} SET active_fg = %d WHERE ad_id = %d", $fg, $id));
	}

	/**
	 * Delete data by id.
	 *
	 * Description: Using id, the relevant record is removed
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @param	int		$ad_id			the id of the record that remove.
	 */
	public function delete_data($ad_id) {
		global $wpdb;
		$tmp = $this->get_datas_byid($ad_id);
		wp_delete_attachment($tmp["basic_val"]["img_id"]);

		$wpdb->query($wpdb->prepare("DELETE FROM {$this->tb_nm} WHERE ad_id = %d", $ad_id));
	}

	/**
	 * drop table.
	 *
	 * Description: when uninstalling this plugin, this function is called.
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 */
	public function delete_img_before_drop_tb() {
		$tmp = array();
		$tmp = $this->get_datas_for_list();

		for($i = 0; $i < count($tmp); $i++) {
			$this->delete_data($tmp[$i]["ad_id"]);
		}
	}

	/**
	 * Get relevant data for site
	 *
	 * @access public
	 * @return void
	 */
	public function get_relevant_data_for_site() {

		global $wpdb;
		$todate = current_time('mysql');

		// Site

		$results = $wpdb->get_results($wpdb->prepare("
			SELECT * FROM {$this->tb_nm}
			WHERE active_fg = 2
				AND (start_date < %s)
				AND (%s < end_date)
				AND (is_front_page=0)
				AND (is_tag=0)
				AND (is_archive=0)
				AND (is_single=0)
				AND (is_page=0)
				AND (is_category=0)
				AND (page_id='')
				AND (post_id='')
				AND (category_id='')
				ORDER BY priority DESC LIMIT 1", $todate, $todate));

		if (!isset($results) && !$results) {
			return false;
		}

		$val = array();
		foreach ($results as $result) {
			$val = parent::maybe_unserialize($result->other_val);
			$val['ad_id'] = $result->ad_id;
			$val['args'] = unserialize($result->args);
		}

		// Check if this is a custom post type AD only

		$post_type_check = true;

		if ( isset($val['args']['post_types']) && count($val['args']['post_types']) > 1 ) {
			foreach ( $val['args']['post_types'] as $post_type ) {
				if ( $post_type ) {
					$post_type_check = false;
				}
			}
		}

		if ( !$post_type_check ) {
			return false;
		}

		return $val;
	}

	/**
	 * get relevant data for front page.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @return	array				datas.
	 */
	public function get_relevant_data_for_frontpage() {
		global $wpdb;
		$todate = current_time('mysql');//date("Y-m-d H:i:00");

		// Home

		$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE active_fg = 2 AND (start_date < %s) AND (%s < end_date) AND (is_front_page=1)  ORDER BY priority ASC LIMIT 1", $todate, $todate));

		// Site

		if ( !isset($results) || empty($results) ) {
			$this->get_relevant_data_for_site();
		}

		if (!isset($results) && !$results) {
			return false;
		}

		$val = array();
		foreach ($results as $result) {
			$val = parent::maybe_unserialize($result->other_val);
			$val['ad_id'] = $result->ad_id;
			$val['args'] = unserialize($result->args);
		}

		return $val;
	}

	/**
	 * get relevant data for tag.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @return	array				datas.
	 */
	public function get_relevant_data_for_tag() {
		global $wpdb;
		$todate = $todate = current_time('mysql');//date("Y-m-d H:i:s");

		// Get ad by is_tag

		$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE active_fg = 2 AND (start_date < %s) AND (%s < end_date) AND (is_tag=1) ORDER BY priority ASC LIMIT 1", $todate, $todate));

		// Site

		if ( !isset($results) || empty($results) ) {
			$this->get_relevant_data_for_site();
		}

		if (!isset($results) && !$results) {
			return false;
		}

		$val = array();
		foreach ($results as $result) {
			$val = parent::maybe_unserialize($result->other_val);
			$val['ad_id'] = $result->ad_id;
			$val['args'] = unserialize($result->args);
		}

		return $val;
	}

	/**
	 * get relevant data for archive.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @return	array				datas.
	 */
	public function get_relevant_data_for_archive() {
		global $wpdb;
		$todate = $todate = current_time('mysql');//date("Y-m-d H:i:s");

		// Get ad by is_archive

		$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE active_fg = 2 AND (start_date < %s) AND (%s < end_date) AND (is_archive=1) ORDER BY priority ASC LIMIT 1", $todate, $todate));

		// Site

		if ( !isset($results) || empty($results) ) {
			$this->get_relevant_data_for_site();
		}

		if (!isset($results) && !$results) {
			return false;
		}

		$val = array();
		foreach ($results as $result) {
			$val = parent::maybe_unserialize($result->other_val);
			$val['ad_id'] = $result->ad_id;
			$val['args'] = unserialize($result->args);
		}

		return $val;
	}

	/**
	 * get relevant data for category.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @return	array				datas.
	 */
	public function get_relevant_data_for_category($cat_id) {
		global $wpdb;
		$todate = $todate = current_time('mysql');//date("Y-m-d H:i:s");

		// Get ad by category ID

		$cat_check = false;

		if (isset($cat_id) && is_numeric($cat_id) && $cat_id > 0) {
			$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE active_fg = 2 AND (start_date < %s) AND (%s < end_date) AND (category_id != '') ORDER BY priority ASC", $todate, $todate));

			if (isset($results) && count($results) > 0) {

				foreach ($results as $result) {
					foreach (explode(",", $result->category_id) as $id) {
						if ($id == $cat_id) {
							$cat_check = true;
							$results = array($result);
							break;
						}
					}
				}
			}
		}

		// Get ad by is_category()

		if (!$results || count($results) <= 0 || !$cat_check) {
			$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE active_fg = 2 AND (start_date < %s) AND (%s < end_date) AND (is_category=1) ORDER BY priority ASC LIMIT 1", $todate, $todate));
		}

		// Site

		if ( !isset($results) || empty($results) ) {
			$this->get_relevant_data_for_site();
		}

		if (!isset($results) && !$results) {
			return false;
		}

		$val = array();
		foreach ($results as $result) {
			$val = parent::maybe_unserialize($result->other_val);
			$val['ad_id'] = $result->ad_id;
			$val['args'] = unserialize($result->args);
		}

		return $val;
	}

	/**
	 * get relevant data for post.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @return	array				datas.
	 */
	public function get_relevant_data_for_post($post_id) {
		global $wpdb;
		$todate = $todate = current_time('mysql');//date("Y-m-d H:i:s");

		// Get ad by post ID

		$post_check = false;

		if (isset($post_id) && is_numeric($post_id) && $post_id > 0) {
			$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE active_fg = 2 AND (start_date < %s) AND (%s < end_date) AND (post_id != '') ORDER BY priority ASC", $todate, $todate));

			if (isset($results) && count($results) > 0) {

				foreach ($results as $result) {
					foreach (explode(",", $result->post_id) as $id) {
						if ($id == $post_id) {
							$post_check = true;
							$results = array($result);
							break;
						}
					}
				}
			}
		}

		// Check based off of category id

		if (!$results || count($results) <= 0 || !$post_check) {
			$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE active_fg = 2 AND (start_date < %s) AND (%s < end_date) AND (category_id != '') ORDER BY priority ASC", $todate, $todate));

			if (isset($results) && count($results) > 0) {

				foreach ($results as $result) {
					foreach (explode(",", $result->category_id) as $id) {

						// Check if this post has this category

						$cat_ids = wp_get_post_categories($post_id);

						if (isset($cat_ids) && is_array($cat_ids) && in_array($id, $cat_ids)) {
							$post_check = true;
							$results = array($result);
							break;
						}
					}
				}
			}
		}

		// Get ad by is_single()

		if (!$results || count($results) <= 0 || !$post_check) {
			$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE active_fg = 2 AND (start_date < %s) AND (%s < end_date) AND (is_single=1) ORDER BY priority ASC LIMIT 1", $todate, $todate));
		}

		// Site

		if ( !isset($results) || empty($results) ) {
			$this->get_relevant_data_for_site();
		}

		if (!isset($results) && !$results) {
			return false;
		}

		$val = array();
		foreach ($results as $result) {
			$val = parent::maybe_unserialize($result->other_val);
			$val['ad_id'] = $result->ad_id;
			$val['args'] = unserialize($result->args);
		}

		return $val;
	}

	/**
	 * get relevant data for page.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @return	array				datas.
	 */
	public function get_relevant_data_for_page($page_id) {
		global $wpdb;
		$todate = $todate = current_time('mysql');//date("Y-m-d H:i:s");

		// Get ad by page ID

		$page_check = false;

		if (isset($page_id) && is_numeric($page_id) && $page_id > 0) {
			$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE active_fg = 2 AND (start_date < %s) AND (%s < end_date) AND (page_id != '') ORDER BY priority ASC", $todate, $todate));

			if (isset($results) && count($results) > 0) {

				foreach ($results as $result) {
					foreach (explode(",", $result->page_id) as $id) {
						if ($id == $page_id) {
							$page_check = true;
							$results = array($result);
							break;
						}
					}
				}
			}
		}

		// Get ad by is_page()

		if (!$results || count($results) <= 0 || !$page_check) {
			$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE active_fg = 2 AND (start_date < %s) AND (%s < end_date) AND (is_page=1) ORDER BY priority ASC LIMIT 1", $todate, $todate));
		}

		// Site

		if ( !isset($results) || empty($results) ) {
			$this->get_relevant_data_for_site();
		}

		if (!isset($results) && !$results) {
			return false;
		}

		$val = array();
		foreach ($results as $result) {
			$val = parent::maybe_unserialize($result->other_val);
			$val['ad_id'] = $result->ad_id;
			$val['args'] = unserialize($result->args);
		}

		return $val;
	}

	/**
	 * get relevant data for custom post type.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @return	array				datas.
	 */
	public function get_relevant_data_for_custom_post_type($custom_post_type) {
		global $wpdb;

		$todate = $todate = current_time('mysql');//date("Y-m-d H:i:s");

		// Get ad by custom post type

		$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$this->tb_nm} WHERE active_fg = 2 AND (start_date < %s) AND (%s < end_date) ORDER BY priority ASC", $todate, $todate));

		// Site

		if ( !isset($results) || empty($results) ) {
			$this->get_relevant_data_for_site();
		}

		if (!isset($results) && !$results) {
			return false;
		}

		$vals = array();
		foreach ($results as $result) {
			$val = array();
			$val = parent::maybe_unserialize($result->other_val);
			$val['ad_id'] = $result->ad_id;
			$val['args'] = unserialize($result->args);
			$vals[] = $val;
		}

		foreach ($vals as $ad) {
			foreach ($ad['args']['post_types'] as $post_type => $val) {
				if ($post_type == $custom_post_type && $val) {
					$val = $ad;
					break;
				}
			}
		}

		return $val;
	}
}
?>